# encoding: utf-8
require "logstash/devutils/rspec/spec_helper"
require "logstash/outputs/bos"
require "logstash/codecs/plain"
require "logstash/event"
require "baidubce/services/bos/bos_client"

describe LogStash::Outputs::Bos do
  let(:logEvent) { LogStash::Event.new }
  let(:output) { LogStash::Outputs::Bos.new }

  before do
    logEvent.set("log", "Logstash Plugin Test String")
    logEvent.set("bucket", "hubble")
    logEvent.set("object", "Logstash/PluginTest")
    logEvent.set("ak", "be80026973e14e2783bd37670c9bff5d")
    logEvent.set("sk", "ed5f08fe9e374fb48fb9d4d1b6d83491")
    logEvent.set("endpoint", "http://bj.bcebos.com")
    output.register
  end

  describe "receive message" do
    output.receive(logEvent)

    it "returns a string" do
      bos = {
        "endpoint" => "http://bj.bcebos.com",
        "ak" => "be80026973e14e2783bd37670c9bff5d",
        "sk" => "ed5f08fe9e374fb48fb9d4d1b6d83491"
      }

      credentials = Auth::BceCredentials.new(
          bos['ak'],
          bos['sk']
      )

      conf = BceClientConfiguration.new(
          credentials,
          bos['endpoint']
      )
      client = Services::BosClient.new(conf)
      result = client.get_object_as_string("hubble", "Logstash/PluginTest")
      expect(result).to eq("Logstash Plugin Test String")
      client.delete_object("hubble", "Logstash/PluginTest")
    end
  end
end
